summaryrefslogtreecommitdiffstats
path: root/pkgs/development
diff options
context:
space:
mode:
authorFabian Affolter <mail@fabian-affolter.ch>2021-12-26 17:55:31 +0100
committerJonathan Ringer <jonringer@users.noreply.github.com>2021-12-28 08:24:06 -0800
commitdc3e2d57ef1561ea7dfa213bffd1ee53588d6866 (patch)
treee99650200635fa33f2a59d64aa32ebf2cc25899d /pkgs/development
parent74ea9f92910295c03dcd58f59853f1c3ca1322a2 (diff)
python3Packages.blockdiag: 2.0.1 -> 3.0.0
Diffstat (limited to 'pkgs/development')
-rw-r--r--pkgs/development/python-modules/blockdiag/default.nix52
1 files changed, 45 insertions, 7 deletions
diff --git a/pkgs/development/python-modules/blockdiag/default.nix b/pkgs/development/python-modules/blockdiag/default.nix
index f5d8b93c4816..34245d93560c 100644
--- a/pkgs/development/python-modules/blockdiag/default.nix
+++ b/pkgs/development/python-modules/blockdiag/default.nix
@@ -1,22 +1,60 @@
-{ lib, buildPythonPackage, fetchFromGitHub
-, setuptools, funcparserlib, pillow, webcolors, reportlab, docutils
+{ lib
+, buildPythonPackage
+, docutils
+, fetchFromGitHub
+, funcparserlib
+, nose
+, pillow
+, ephem
+, pythonOlder
+, pytestCheckHook
+, reportlab
+, setuptools
+, webcolors
+, python
}:
buildPythonPackage rec {
pname = "blockdiag";
- version = "2.0.1";
+ version = "3.0.0";
+ format = "setuptools";
+
+ disabled = pythonOlder "3.7";
src = fetchFromGitHub {
owner = "blockdiag";
repo = "blockdiag";
rev = version;
- sha256 = "1cvcl66kf4wdh2n4fdk37zk59lp58wd2fhf84n7pbn0lilyksk5x";
+ sha256 = "sha256-j8FoNUIJJOaahaol1MRPyY2jcPCEIlaAD4bmM2QKFFI=";
};
- propagatedBuildInputs = [ setuptools funcparserlib pillow webcolors reportlab docutils ];
+ propagatedBuildInputs = [
+ setuptools
+ funcparserlib
+ pillow
+ webcolors
+ reportlab
+ docutils
+ ];
+
+ checkInputs = [
+ ephem
+ nose
+ pytestCheckHook
+ ];
+
+ pytestFlagsArray = [
+ "src/blockdiag/tests/"
+ ];
+
+ disabledTests = [
+ # Test require network access
+ "test_app_cleans_up_images"
+ ];
- # require network and fail
- doCheck = false;
+ pythonImportsCheck = [
+ "blockdiag"
+ ];
meta = with lib; {
description = "Generate block-diagram image from spec-text file (similar to Graphviz)";